@@ -79,6 +79,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub use checkout_core::internal_context::InternalContext;
 
             use std::env;
+            use tokio::task;
             use checkout_core::cloud_pubsub;
             use checkout_core::dropshot;
             use checkout_core::dropshot::endpoint;
@@ -136,37 +137,38 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 }
             }
 
-            pub async fn start_payment_processing(
+            pub fn start_payment_processing(
                 subscription_name: String,
                 internal_ctx: InternalContext,
                 context_provider: Arc<super::#server_type_name>,
             ) {
-                let subscription = internal_ctx.pubsub_client.subscribe(subscription_name);
-
-                while subscription.client().is_running() {
-                    match subscription.get_messages::<Message>().await {
-                        Ok(messages) => {
-                            for (result, ack_id) in messages {
-                                match result {
-                                    Ok(message) => {
-                                        println!("Received: {:?}", message);
-                                        match context_provider.new_context().await {
-                                            Ok(mut ctx) => {
-                                                let processing_result = process_handler(&internal_ctx, &mut ctx, message.0).await;
-                                                if processing_result.is_ok() {
-                                                    subscription.acknowledge_messages(vec![ack_id]).await;
+                task::spawn(async move {
+                    let subscription = internal_ctx.pubsub_client.subscribe(subscription_name);
+                    while subscription.client().is_running() {
+                        match subscription.get_messages::<Message>().await {
+                            Ok(messages) => {
+                                for (result, ack_id) in messages {
+                                    match result {
+                                        Ok(message) => {
+                                            println!("Received: {:?}", message);
+                                            match context_provider.new_context().await {
+                                                Ok(mut ctx) => {
+                                                    let processing_result = process_handler(&internal_ctx, &mut ctx, message.0).await;
+                                                    if processing_result.is_ok() {
+                                                        subscription.acknowledge_messages(vec![ack_id]).await;
+                                                    }
                                                 }
+                                                Err(_) => {}
                                             }
-                                            Err(_) => {}
                                         }
+                                        Err(e) => eprintln!("Failed to parse message: {}", e),
                                     }
-                                    Err(e) => eprintln!("Failed to parse message: {}", e),
                                 }
                             }
+                            Err(e) => eprintln!("Failed to pull PubSub messages: {}", e),
                         }
-                        Err(e) => eprintln!("Failed to pull PubSub messages: {}", e),
                     }
-                }
+                });
             }
 
             #[endpoint {
